From 44dcc1a35f398b9cfcde9b81188b5fc3357df1b7 Mon Sep 17 00:00:00 2001 From: =?UTF-8?q?S=C3=A9bastien=20Theys?= Date: Tue, 2 Jan 2024 13:53:40 +0100 Subject: [PATCH] [FIX] mail: batch insert of fetched channel members MIME-Version: 1.0 Content-Type: text/plain; charset=UTF-8 Content-Transfer-Encoding: 8bit This reduces the time of the method from 400ms to 40ms on my machine. closes odoo/odoo#147814 Signed-off-by: Alexandre Kühn (aku) --- addons/mail/static/src/core/common/thread_service.js | 10 ++++++---- 1 file changed, 6 insertions(+), 4 deletions(-) diff --git a/addons/mail/static/src/core/common/thread_service.js b/addons/mail/static/src/core/common/thread_service.js index 568fbaa274c..67bf78d232a 100644 --- a/addons/mail/static/src/core/common/thread_service.js +++ b/addons/mail/static/src/core/common/thread_service.js @@ -87,11 +87,13 @@ export class ThreadService { channelMembers = results["channelMembers"][0][1]; } thread.memberCount = results["memberCount"]; - for (const channelMember of channelMembers) { - if (channelMember.persona || channelMember.partner) { - thread.channelMembers.add({ ...channelMember, thread }); + Record.MAKE_UPDATE(() => { + for (const channelMember of channelMembers) { + if (channelMember.persona || channelMember.partner) { + thread.channelMembers.add({ ...channelMember, thread }); + } } - } + }); } /**